@@ -1,4 +1,8 @@
-"""Utilities for bootstrapping streamparse projects."""
+"""
+Utilities for bootstrapping streamparse projects.
+"""
+from __future__ import absolute_import, print_function, unicode_literals
+
 from contextlib import contextmanager
 import os
 import sys
@@ -35,20 +39,20 @@ def _cd(path):
 
 def _mkdir(path):
     path = '{}/{}'.format(_path_prefix, path) if _path_prefix != '' else path
-    print '    {:<18} {}'.format(green('create'), path)
+    print('    {:<18} {}'.format(green('create'), path))
     os.makedirs(path)
 
 
 def _cp(src, dest):
     dest = '{}/{}'.format(_path_prefix, dest) if _path_prefix != '' else dest
-    print '    {:<18} {}'.format(green('create'), dest)
+    print('    {:<18} {}'.format(green('create'), dest))
     shutil.copy(src, dest)
 
 
 def _touch(filename):
     filename = '{}/{}'.format(_path_prefix, filename) if _path_prefix != '' \
                else filename
-    print '    {:<18} {}'.format(green('create'), filename)
+    print('    {:<18} {}'.format(green('create'), filename))
     with open(filename, 'w'):
         pass
 
@@ -56,7 +60,7 @@ def _touch(filename):
 def _generate(template_filename, dest):
     dest = '{}/{}'.format(_path_prefix, dest) if _path_prefix != '' \
            else dest
-    print '    {:<18} {}'.format(green('create'), dest)
+    print('    {:<18} {}'.format(green('create'), dest))
     template = _env.get_template(template_filename)
     with open(dest, 'w') as fp:
         fp.write(template.render())
@@ -67,12 +71,11 @@ def quickstart(project_name):
     # glob.glob('project/**/*') and then we copy everything that's doesn't have
     # jinja2 in filename, generate the jinja2 stuff
     if os.path.exists(project_name):
-        print '{}: folder "{}" already exists'.format(red('error'),
-                                                      project_name)
+        print('{}: folder "{}" already exists'.format(red('error'),
+                                                      project_name))
         sys.exit(1)
 
-    print '\nCreating your {} streamparse project...'\
-          .format(blue(project_name))
+    print('\nCreating your %s streamparse project...' % (blue(project_name)))
     _env.globals['project_name'] = project_name
 
     _mkdir(project_name)
@@ -96,7 +99,7 @@ def quickstart(project_name):
             _cp(_here('project', 'virtualenvs', 'wordcount.txt'),
                 'wordcount.txt')
 
-    print 'Done.\n'
-    print ('Try running your topology locally with:\n\n'
+    print('Done.\n')
+    print(('Try running your topology locally with:\n\n'
            '\tcd {}\n'
-           '\tsparse run'.format(project_name))
+           '\tsparse run').format(project_name))
