@@ -4,8 +4,9 @@
   :target-path "_build"
   :min-lein-version "2.0.0"
   :jvm-opts ["-client"]
-  :dependencies  [[org.apache.storm/storm-core "0.9.1-incubating"]
-                  [com.parsely/streamparse "0.0.3-SNAPSHOT"]]
+  :dependencies  [[org.apache.storm/storm-core "0.9.2-incubating"]
+                  [com.parsely/streamparse "0.0.3-SNAPSHOT"]
+                  ]
   :jar-exclusions     [#"log4j\.properties" #"backtype" #"trident" #"META-INF" #"meta-inf" #"\.yaml"]
   :uberjar-exclusions [#"log4j\.properties" #"backtype" #"trident" #"META-INF" #"meta-inf" #"\.yaml"]
   )
