@@ -1,11 +1,20 @@
-"""Base Spout classes."""
-from ipc import read_handshake, read_command, send_message, json, _stdout
-from base import Component
+"""
+Base Spout classes.
+"""
+
+from __future__ import absolute_import, print_function, unicode_literals
+
+from six import PY3
+
+from .base import Component
+from .ipc import read_handshake, read_command, send_message, json, _stdout
 
 
 class Spout(Component):
-    """Base class for all streamparse spouts.  For more information on spouts,
-    consult Storm's `Concepts documentation <http://storm.incubator.apache.org/documentation/Concepts.html>`_.
+    """Base class for all streamparse spouts.
+
+    For more information on spouts, consult Storm's
+    `Concepts documentation <http://storm.incubator.apache.org/documentation/Concepts.html>`_.
     """
 
     def initialize(self, storm_conf, context):
@@ -33,8 +42,10 @@ class Spout(Component):
         pass
 
     def fail(self, tup_id):
-        """Called when a tuple fails in the topology, a Spout can choose to
-        emit the tuple again or ignore the fail.  Default is to ignore.
+        """Called when a tuple fails in the topology
+
+        A Spout can choose to emit the tuple again or ignore the fail. The
+        default is to ignore.
 
         :param tup_id: the ID of the tuple that has failed in the topology
                        either due to a bolt calling ``fail()`` or a tuple
@@ -44,6 +55,12 @@ class Spout(Component):
         pass
 
     def next_tuple(self):
+        """Implement this function to emit tuples as necessary.
+
+        This function should not block, or Storm will think the
+        spout is dead. Instead, let it return and streamparse will
+        send a noop to storm, which lets it know the spout is functioning.
+        """
         raise NotImplementedError()
 
     def emit(self, tup, tup_id=None, stream=None, direct_task=None):
@@ -77,8 +94,9 @@ class Spout(Component):
         send_message(msg)
 
     def emit_many(self, tuples, tup_id=None, stream=None, direct_task=None):
-        """A more efficient way to send many tuples, dumps out all tuples to
-        STDOUT instead of writing one at a time.
+        """A more efficient way to send many tuples.
+
+        Dumps out all tuples to STDOUT instead of writing one at a time.
 
         :param tuples: a two-dimensional ``list`` representing the tuples to
                        send to Storm.  Tuples should contain only
@@ -108,14 +126,22 @@ class Spout(Component):
         for tup in tuples:
             msg['tuple'] = tup
             lines.append(json.dumps(msg))
-        _stdout.write("{}\nend\n".format("\nend\n".join(lines)))
+        wrapped_msg = "{}\nend\n".format("\nend\n".join(lines)).encode('utf-8')
+        if PY3:
+            _stdout.flush()
+            _stdout.buffer.write(wrapped_msg)
+        else:
+            _stdout.write(wrapped_msg)
         _stdout.flush()
 
     def run(self):
-        """Main run loop for all spouts. Performs initial handshake with Storm
-        and reads tuples handing them off to subclasses.  Any exceptions are
-        caught and logged back to Storm prior to the Python process exits.
-        Subclasses should not override this method.
+        """Main run loop for all spouts.
+
+        Performs initial handshake with Storm and reads tuples handing them off
+        to subclasses.  Any exceptions are caught and logged back to Storm
+        prior to the Python process exiting.
+
+        Subclasses should **not** override this method.
         """
         storm_conf, context = read_handshake()
         try:
